@@ -6,6 +6,7 @@ seconds_listen_channel = 5*60 # seconds
 my_username = "fenton"
 debug = True
 monitored_channels = {} # "channel_name": time_i_last_chatted
+the_printer = None
 
 def generate_actions_from_irc_message(args,printer):
     # Generate a list of action based on input args.  The design of this
@@ -15,6 +16,7 @@ def generate_actions_from_irc_message(args,printer):
     # notification if the message is on a channel I'm monitoring, or play a
     # sound if a message is directly to me.
     global monitored_channels
+    global the_printer = printer
     from_who = args["from_who"]
     channel = args["channel"]
     message = args["message"]
@@ -74,8 +76,10 @@ def display_alert(args,printer):
     alert_title = args['alert_title']
     alert_message = args['alert_message']
     urgency = args['urgency']
+    if debug: 
+        printer ("title/message/urgency", alert_title + "/" + alert_message + "/" + urgency)
     cmd = construct_notification_command(alert_title, alert_message, urgency)
-    #    pdb.set_trace()
+    # pdb.set_trace()
     if debug: 
         printer ("The Command:", str(cmd))
     call(cmd)    
